@@ -35,6 +35,11 @@ from hrefutils import ext_mime_map, mime_group_map
 
 import unicodedata
 
+_launcher_version = 20240522
+
+_RS = chr(30) # record separator
+_US = chr(31) # unit separator
+
 def _utf8str(p):
     if p is None:
         return None
@@ -49,8 +54,6 @@ def _unicodestr(p):
         return p
     return p.decode('utf-8', errors='replace')
 
-_launcher_version = 20240211
-
 _PKG_VER = re.compile(r'''<\s*package[^>]*version\s*=\s*["']([^'"]*)['"][^>]*>''', re.IGNORECASE)
 
 # Wrapper Class is used to peform record keeping for Sigil.  It keeps track of modified,
@@ -122,6 +125,7 @@ class Wrapper(object):
         self.colors = None
         self.using_automate = False
         self.automate_parameter = None
+        self.font_mangling = {}
         # File selected in Sigil's Book Browser
         self.selected = []
         cfg = ''
@@ -145,6 +149,13 @@ class Wrapper(object):
             self.uifont = cfg_lst.pop(0)
             self.using_automate = (cfg_lst.pop(0) == "InAutomate")
             self.automate_parameter = cfg_lst.pop(0);
+            mangle_list = []
+            font_info = cfg_lst.pop(0)
+            if font_info and font_info != "":
+                mangle_list = font_info.split(_RS);
+            for finfo in mangle_list:
+                fontpath, algo = finfo.split(_US);
+                self.font_mangling[fontpath] = algo
             self.selected = cfg_lst
         os.environ['SigilGumboLibPath'] = self.get_gumbo_path()
 
@@ -812,6 +823,12 @@ class Wrapper(object):
         href = urldecodepart(href)
         return self.href_to_id.get(href, ow)
 
+    # new in Sigil 2.2.0
+    def map_font_bookpath_to_mangling_algorithm(self, bookpath, ow):
+        if bookpath in self.font_mangling:
+            return self.font_mangling[bookpath]
+        return ow
+
     # new in Sigil 1.0
     def map_bookpath_to_id(self, bookpath, ow):
         bookpath = _unicodestr(bookpath)
